@@ -1,5 +1,5 @@
 import paramiko
-class ftpUtils:
+class bgftpUtil:
     def putpic(self,filepath,filename):
         # # 要传输文件的路径
         # filepath = "./myname.jpg"
