@@ -1,7 +1,7 @@
 import json
 import pandas as pd
 from sqlalchemy import create_engine
-class mysqlUtil:
+class bgmysqlUtil:
     def __init__(self):
         mysql_username = 'test'
         mysql_password = 'test'
